/* @import url('reset.css'); */
html,
body,
#app {
    margin: 0;
    height: 100%;
    font-family: "Helvetica Neue", Arial, sans-serif;
    color: #333;
}

.menu {
    border-bottom: 1px solid gray;
}

.menu {
    padding-left: 40px;
}

.alert {
    color: darkgray;
}

.alert>svg {
    margin-top: 2px;
    width: 18px;
    height: 18px;
    stroke: orange;
    stroke-width: 2px;
}

.icn>svg {
    stroke-width: 2px;
}

.logo {
    height: 20px;
    width: 20px;
    transform: scaleX(-1);
    vertical-align: bottom;
    margin-right: 0.25em;
    stroke: #ccc;
    stroke-width: 1;
    stroke-linecap: round;
    stroke-linejoin: round;
    fill: #3979F7;
}

.logo:hover {
    fill: #FF9300;
}

.alert>svg {
    position: relative;
    top: 2px;
}

.table {
    border-collapse: collapse;
    border: 0;
    width: 100%;
    height: 100%;
}

.table th {
    font-weight: normal;
    padding: 0.5em;
    vertical-align: center;
    text-align: left;
}

.table th>input {
    border: 0px;
    font-size: 14px;
}

.menu button {
    float: right;
    font-size: 14px;
    background-color: white;
    color: black;
    border-radius: 3px;
    border: 1px solid darkgray;
    margin-left: 4px;
    padding: 2px 6px 3px 6px;
}

.menu button.active {
    background-color: #3979F7;
    border-color: #3979F7;
    color: white;
}

.menu button:disabled {
    background-color: lightgray;
    border-color: darkgray;
    color: darkgray;
}

.menu button:hover {
    background-color: #93B3F2;
    border-color: #93B3F2;
    color: white;
}

.menu button.active:hover {
    background-color: #3979F7;
    border-color: #3979F7;
    color: white;
}

.table td {
    margin: 0.5em;
    vertical-align: top;
}

.files {
    width: 20%;
    padding-top: 0.5em;
    padding-left: 0.5em;
    height: 100%;
}

.entry, .preview {
    width: 40%;
    height: 100%;
}

.entry {
    padding-left: 0.5em;
    padding-right: 0.5em;
}

.preview {
    padding-left: 0.5em;
    padding-right: 0.5em;
    height: 100%;
}

.preview img {
    max-width: 120px;
}

.preview>div {
    height: 100%;
    overflow-y: scroll;
}

.preview .twemoji{
    width: 1em;
    height: 1em;
}

textarea {
    width: 100%;
    height: 100%;
    vertical-align: top;
    border: none;
    resize: none;
    outline: none;
    background-color: #f6f6f6;
    font-size: 14px;
    font-family: "Monaco", courier, monospace;
    overflow-y: scroll;
}

code {
    color: #f66;
}

.feather {
    width: 16px;
    height: 16px;
    stroke: currentColor;
    stroke-width: 1;
    stroke-linecap: round;
    stroke-linejoin: round;
    fill: none;
}

.listing {
    list-style: none;
    margin: 0;
    padding: 0;
}

.listing li {
    cursor: pointer;
    padding-top: 2px;
    padding-bottom: 2px;
}

.listing li>svg {
    position: relative;
    top: 2px;
}

.listing li:hover {
    background-color: #e3f7fc;
}

.breadcrumb a {
    cursor: pointer;
}

p.breadcrumb {
    border-bottom: 1px solid gray;
    padding-bottom: 1em;
}

.image-preview {
    margin-top: 1em;
    padding: 1em;
    border-top: 1px solid gray;
    border-bottom: 1px solid gray;
}

.image-preview>button {
    float: right;
}

.image-preview>button>svg {
    position: relative;
    top: 2px;
    stroke-width: 2px;
}

.upload {
    padding-bottom: 1em;
    border-bottom: 1px solid gray;
}

.icn-spinner {
    width: 16px;
    height: 16px;
    animation: spin-animation 1s infinite linear;
    display: inline-block;
}

@keyframes spin-animation {
    0% {
        transform: rotate(0deg);
    }

    100% {
        transform: rotate(359deg);
    }
}