.duckdown {
    --bg-color: #51ABC4;
    --txt-color: #147C99;
}

body {
    background: var(--bg-color);
    color: var(--txt-color);
}

#logo{
    width: 200px;
    height: 200px;
}

.user_edit {
    position: absolute;
    top: 2px;
    right: 2px;
}